import numpy as np

def _bw_nrd0(x):
    """
    A function to apply the Silverman's ‘rule of thumb’ for the bandwidth selection of a Gaussian kernel density estimator.

    Parameters
    ----------

    x: numpy.array
        a vector of numerical values

    Returns
    -------

    float
        the bandwith calculated with the Silverman's ‘rule of thumb’

    """ 
    if len(x) < 2:
        raise(Exception("need at least 2 data points"))

    hi = np.std(x, ddof=1)
    q75, q25 = np.percentile(x, [75 ,25])
    iqr = q75 - q25
    lo = min(hi, iqr/1.34)

    if not ((lo == hi) or (lo == abs(x[0])) or (lo == 1)):
        lo = 1

    return 0.9 * lo *len(x)**-0.2
